<?php
function cth_eventres_plugin_stripe_process_payment_for_modal() {
	if(isset($_POST['action']) && $_POST['action'] == 'gather_event_stripe' && wp_verify_nonce($_POST['stripe_nonce'], 'gather_event_stripe_action')) {
 
		global $gather_stripe_options;

		if( !defined('STRIPE_LOG_FILE') ) define("STRIPE_LOG_FILE", "./stripe.log");

		//$forUnixTimestamp = new DateTime;
 
		// load the stripe libraries
		require_once CTH_EVENTRES_DIR .'includes/stripe-php/init.php';
 
		// retrieve the token generated by stripe.js
		$token = $_POST['stripeToken'];
		$email = trim($_POST['email']);
		$first_name = trim($_POST['first_name']);
		$last_name = trim($_POST['last_name']);
		$quantity = trim($_POST['item_quantity']);
		// check if we are using test mode
		if(isset($gather_stripe_options['stripe_test_mode']) && $gather_stripe_options['stripe_test_mode']) {
			$secret_key = $gather_stripe_options['test_secret_key'];
			if( !defined('STRIPE_DEBUG') ) define("STRIPE_DEBUG", true);
		} else {
			$secret_key = $gather_stripe_options['live_secret_key'];
			if( !defined('STRIPE_DEBUG') ) define("STRIPE_DEBUG", false);
		}

		$currency = $gather_stripe_options['currency'];

		// registration key
		$auth_key = defined( 'AUTH_KEY' ) ? AUTH_KEY : '';
	    $pur_key = strtolower( md5( $email . date( get_option('date_format') ) . $auth_key . uniqid( 'gatherevent', true ) ) );  // Unique key

 		$eventres_add_fields            = isset( $gather_stripe_options['add_fields'] ) ? $gather_stripe_options['add_fields'] : array(); // get_option('eventres_add_fields','' );

		// Use Stripe's library to make requests...
		\Stripe\Stripe::setApiKey( $secret_key );

		$using_discount = false;
		$coupon_type = '';
		$coupon_amount = 0;
		if(isset($_POST['coupon_code']) && $_POST['coupon_code'] != '' ) {
			$using_discount = true;
			// we have a discount code, now check that it is valid			
			try {
				$coupon = \Stripe\Coupon::retrieve(trim($_POST['coupon_code']));
				// echo'<pre>';
				// var_dump($coupon);die;
				if(isset($coupon->percent_off)) {
					$coupon_type = 'percent';
					$coupon_amount = $coupon->percent_off;
				}elseif( isset($coupon->amount_off) ){
					$coupon_type = 'amount';
					$coupon_amount = $coupon->amount_off;
				}
				// if we got here, the coupon is valid
			} catch (Exception $e) {
 				if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Error: " . $e->getMessage() . PHP_EOL, 3, STRIPE_LOG_FILE);
				// an exception was caught, so the code is invalid
				//wp_die(__('The coupon code you entered is invalid. Please click back and enter a valid code, or leave it blank for no discount.', 'cth-gather-plugins'), 'Error');
 
			}
		}

		if(isset($_POST['success_redirect']) && $_POST['success_redirect']){
			$success_redirect = esc_url($_POST['success_redirect'] );
		}else{
			$success_redirect = get_permalink( $gather_stripe_options['stripe_success_page'] ) ;
		}
		if(isset($_POST['failed_redirect']) && $_POST['failed_redirect']){
			$failed_redirect = esc_url($_POST['failed_redirect'] );
		}else{
			$failed_redirect = get_permalink( $gather_stripe_options['stripe_failed_page'] ) ;
		}
 
		if(isset($_POST['stripe_plan']) && $_POST['stripe_plan'] != '') { // process a recurring payment
 
			// recurring payment setup will go here

			$stripe_plan = base64_decode($_POST['stripe_plan']);

			//tax
			if(isset($gather_stripe_options['stripe_tax']) && $gather_stripe_options['stripe_tax'] && floatval($gather_stripe_options['stripe_tax'])){
				$sub_tax = floatval($gather_stripe_options['stripe_tax']) ;
			}else {
				$sub_tax = 0;
			}

			//default subscription post id
			$res_id = 0;
			try {	
				//check if user is logged in or not
				if( is_user_logged_in() ){
					$customer_id = get_user_meta( get_current_user_id(), '_striperes_customer_id', true );
				}else{
					$customer_id = false;
				}
				$will_create_new_subscription = false;

				if($customer_id){
					//user is logged in and has customer id
					//process update customer's subscription plan and wp subscription details also

					if(isset($gather_stripe_options['user_multiple_reg']) && $gather_stripe_options['user_multiple_reg'] ) {
						$will_create_new_subscription = true;
					}else{
						$customer = \Stripe\Customer::retrieve($customer_id);
						if(!isset($customer->metadata['subscription_id'])){
							$will_create_new_subscription = true;
						}
					}
				}else{
					//user logged in or not but has no customer id
					
					$will_create_new_subscription = true;

				}

				

				if($will_create_new_subscription) {
					// creating a subscription post type for admin management
					$res_datas = array();
			        if(isset($first_name) && isset($last_name)){
			            $res_datas['post_title'] = $first_name .' '.$last_name;
			        }else{
			            $res_datas['post_title'] = $email;
			        }
			        
			        //$res_datas['post_name'] = '';
			        $res_datas['post_content'] = '';
			        //$res_datas['post_author'] = '0';// default 0 for no author assigned
			        $res_datas['post_status'] = 'publish';
			        $res_datas['post_type'] = 'cth_striperes';//cth_striperes

			        $res_id = wp_insert_post($res_datas ,true );

			        if (is_wp_error($res_id)) {
			        	if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Insert subscription post error: " . $res_id->get_error_message() . PHP_EOL, 3, STRIPE_LOG_FILE);
			            //print( $res_id->get_error_message() );
			        }
			        //else{

			        	// //$res_meta_datas = array();
				        // $res_meta_datas['pur_pass']     		= $subscription->plan->name; //trim($_POST['os0']);
				        // $res_meta_datas['pur_plan_id']     		= $subscription->plan->id; //trim($_POST['os0']);
				        // $res_meta_datas['pur_price']     		= number_format( $subscription->plan->amount / 100 , 2, '.',','); // $res_post_datas['price'];
				        // $res_meta_datas['pur_quantity']     	= $subscription->quantity;// $quantity;
				        // $res_meta_datas['pur_date']     		= date( get_option('date_format'), current_time( 'timestamp' ) );
				        // $res_meta_datas['pur_currency']     	= $subscription->plan->currency ;// $currency;

				        // $res_meta_datas['pur_key'] 				= $pur_key;
				        // $res_meta_datas['pur_custom'] 			= uniqid();
				        // $res_meta_datas['pur_gateway']     		= 'Stripe payment';//.$charge->sources->object;
				        // $res_meta_datas['pur_status']     		= $subscription->status;

				        
				        // $res_meta_datas['pur_fname'] 			= $first_name;
				        // $res_meta_datas['pur_lname'] 			= $last_name;
				        // $res_meta_datas['pur_email'] 			= $email;

				        // //strore Stripe customer id in the reg
				        // $res_meta_datas['pur_customer_id'] 		= $customer_id ;
				        
			            

				    //}

				}



				$res_meta_datas = array();

				$subscriptionobjmeta = array();
		        $subscriptionobjmeta['res_id'] = $res_id;
		        // $subscriptionobjmeta['event_pass']     	= $stripe_plan;
		        // $subscriptionobjmeta['sub_plan']     	= $stripe_plan;
		        // $subscriptionobjmeta['quantity']     	= $quantity;

	            if(!empty($eventres_add_fields)){
	                foreach ($eventres_add_fields as $key => $field) {
	                    $field_name = str_replace(array(" ","-"), "_", $field['name']);
	                    if(!isset($res_meta_datas[$field_name])){
	                        $res_meta_datas[$field_name] = trim($_POST[$field_name]); 
	                        $subscriptionobjmeta[$field_name] = trim($_POST[$field_name]); 
	                    }
	                }
	            }


				if($customer_id){
					//user is logged in and has customer id
					//process update customer's subscription plan and wp subscription details also

					if(isset($gather_stripe_options['user_multiple_reg']) && $gather_stripe_options['user_multiple_reg'] ) {
						if($using_discount){
							$subscription = \Stripe\Subscription::create(array(
							  	"customer" => $customer_id,
							  	"plan" => $stripe_plan,
							  	'coupon'=> trim($_POST['coupon_code']),
							  	'quantity'=>$quantity,
							  	'metadata' => $subscriptionobjmeta,
							  	"tax_percent" => $sub_tax,
							));
						}else{
							$subscription = \Stripe\Subscription::create(array(
							  	"customer" => $customer_id,
							  	"plan" => $stripe_plan,
							  	'quantity'=>$quantity,
							  	'metadata' => $subscriptionobjmeta,
							  	"tax_percent" => $sub_tax,
							));
						}
						//$will_create_new_subscription = true;
					}else{
						$customer = \Stripe\Customer::retrieve($customer_id);
						if(isset($customer->metadata['subscription_id'])){
							$subscription = \Stripe\Subscription::retrieve( $customer->metadata['subscription_id'] );
							$subscription->plan = $stripe_plan;
							$subscription->quantity = $quantity;
							if($using_discount){
								$subscription->coupon = trim($_POST['coupon_code']);
							}

							$subscription->prorate = true;//change plan immediately
							$subscription->save();


							// update subscription details

							$sub_post_args = array(
								'post_type' => 'cth_striperes',
								'meta_query' => array(
									array(
										'key' => 'pur_customer_id',
										'value' => $customer_id,
									)
								)
							 );
							$sub_posts = get_posts( $sub_post_args );

							if(is_array($sub_posts) && count($sub_posts)){
								$sub_posts = $sub_posts[0];
								$subscription = \Stripe\Subscription::retrieve( $subscription->id );

								update_post_meta( $sub_posts->ID, 'pur_pass', $subscription->plan->name );
								update_post_meta( $sub_posts->ID, 'pur_plan_id', $subscription->plan->id );
								update_post_meta( $sub_posts->ID, 'pur_price', number_format( $subscription->plan->amount / 100 , 2, '.',',') );
								update_post_meta( $sub_posts->ID, 'pur_quantity', $subscription->quantity );
								update_post_meta( $sub_posts->ID, 'pur_currency', $subscription->plan->currency );

							}
							


						}else{
							if($using_discount){
								$subscription = \Stripe\Subscription::create(array(
								  	"customer" => $customer_id,
								  	"plan" => $stripe_plan,
								  	'coupon'=> trim($_POST['coupon_code']),
								  	'quantity'=>$quantity,
								  	'metadata' => $subscriptionobjmeta,
								  	"tax_percent" => $sub_tax,
								));
							}else{
								$subscription = \Stripe\Subscription::create(array(
								  	"customer" => $customer_id,
								  	"plan" => $stripe_plan,
								  	'quantity'=>$quantity,
								  	'metadata' => $subscriptionobjmeta,
								  	"tax_percent" => $sub_tax,
								));
							}
							//$will_create_new_subscription = true;
						}
					}
				}else{
					//user logged in or not but has no customer id
					$customer = \Stripe\Customer::create(array(
					    'email' => $email,
					    'source'  => $token,
					    'metadata' => array( "first_name" => $first_name, "last_name" => $last_name ), // You can have up to 20 keys, with key names up to 40 characters long and values up to 500 characters long.
					));

					if( is_user_logged_in() ) {
						// add customer id to use later
						add_user_meta( get_current_user_id() , '_striperes_customer_id', $customer->id);
					}else{
						if(isset($gather_stripe_options['register_user']) && $gather_stripe_options['register_user'] ) {
							//register new user when register to event
							$new_username = sanitize_user($first_name.'_'.$last_name, true);
							$new_user = register_new_user($new_username, $email);
							if ( !is_wp_error($new_user) ) {
								
								add_user_meta( $new_user, '_striperes_customer_id', $customer->id);
								
							}else{
								if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Stripe add new user error: " . $new_user->get_error_message() . PHP_EOL, 3, STRIPE_LOG_FILE);
								wp_die( $new_user->get_error_message(), 'Error' );
							}
						}
					}

					if($using_discount){
						$subscription = \Stripe\Subscription::create(array(
						  	"customer" => $customer->id,
						  	"plan" => $stripe_plan,
						  	'coupon'=> trim($_POST['coupon_code']),
						  	'quantity'=>$quantity,
						  	'metadata' => $subscriptionobjmeta,
						  	"tax_percent" => $sub_tax,
						));
					}else{
						$subscription = \Stripe\Subscription::create(array(
						  	"customer" => $customer->id,
						  	"plan" => $stripe_plan,
						  	'quantity'=>$quantity,
						  	'metadata' => $subscriptionobjmeta,
						  	"tax_percent" => $sub_tax,
						));
					}

					//if(!(isset($gather_stripe_options['user_multiple_reg']) && $gather_stripe_options['user_multiple_reg'] ) ) {
						//$customer->metadata = array( "first_name" => $first_name, "last_name" => $last_name, 'subscription_id' => $subscription->id ); // You can have up to 20 keys, with key names up to 40 characters long and values up to 500 characters long.
						//$customer->metadata['subscription_id'] = $subscription->id ;
						//$customer->save();
					//}

					$customer_id = $customer->id;
					//$will_create_new_subscription = true;

				}



				// if( is_user_logged_in() ){
				// 	$customer_id = get_user_meta( get_current_user_id(), '_striperes_customer_id', true );
				// 	if($customer_id){

				// 	}
				// }else{
				// 	//has no Stripe customer id
					
				// 	if(isset($gather_stripe_options['register_user']) && $gather_stripe_options['register_user'] ) {
				// 		//register new user when register to event
				// 		$new_username = sanitize_user($first_name.'_'.$last_name, true);
				// 		$new_user = register_new_user($new_username, $email);
				// 		if ( !is_wp_error($new_user) ) {
							
				// 			add_user_meta( $new_user, '_striperes_customer_id', $customer->id);
							
				// 		}else{
				// 			if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Stripe add new user error: " . $new_user->get_error_message() . PHP_EOL, 3, STRIPE_LOG_FILE);
				// 		}
				// 	}
				// 	//$customer_id = false;
				// }


				

				// if($using_discount){
				// 	$subscription = \Stripe\Subscription::create(array(
				// 	  	"customer" => $customer->id,
				// 	  	"plan" => $stripe_plan,
				// 	  	'coupon'=> trim($_POST['coupon_code']),
				// 	  	'quantity'=>$quantity,
				// 	));
				// }else{
				// 	$subscription = \Stripe\Subscription::create(array(
				// 	  	"customer" => $customer->id,
				// 	  	"plan" => $stripe_plan,
				// 	  	'quantity'=>$quantity,
				// 	));
				// }

				if($will_create_new_subscription) {


					if($res_id) {

			        	//$res_meta_datas = array();
				        $res_meta_datas['pur_pass']     		= $subscription->plan->name; //trim($_POST['os0']);
				        $res_meta_datas['pur_plan_id']     		= $subscription->plan->id; //trim($_POST['os0']);
				        $res_meta_datas['pur_price']     		= number_format( $subscription->plan->amount / 100 , 2, '.',','); // $res_post_datas['price'];
				        $res_meta_datas['pur_quantity']     	= $subscription->quantity;// $quantity;

				        // $forUnixTimestamp->setTimestamp($subscription->created);
				        // $res_meta_datas['pur_date']     		= $forUnixTimestamp->format(get_option('date_format')); // date( get_option('date_format'), current_time( 'timestamp' ) );

				        $res_meta_datas['pur_date']     		= $subscription->created; // date( get_option('date_format'), current_time( 'timestamp' ) );
				        $res_meta_datas['pur_currency']     	= $subscription->plan->currency ;// $currency;

				        $res_meta_datas['pur_key'] 				= $pur_key;
				        $res_meta_datas['pur_custom'] 			= uniqid();
				        $res_meta_datas['pur_gateway']     		= 'Stripe payment';//.$charge->sources->object;
				        $res_meta_datas['pur_status']     		= 'created';// $subscription->status;

				        //$forUnixTimestamp->setTimestamp($subscription->current_period_start);
				        $res_meta_datas['current_period_start']     		= $subscription->current_period_start;

				        //$forUnixTimestamp->setTimestamp($subscription->current_period_end);
				        $res_meta_datas['current_period_end']     		= $subscription->current_period_end;

				        if(isset($subscription->trial_start)){
				        	//$forUnixTimestamp->setTimestamp($subscription->trial_start);
				        	$res_meta_datas['trial_start']     		= $subscription->trial_start;
				        }
				        
				        if(isset($subscription->trial_end)){
				        	//$forUnixTimestamp->setTimestamp($subscription->trial_end);
				        	$res_meta_datas['trial_end']     		= $subscription->trial_end;
				        }
				        

				        
				        $res_meta_datas['pur_fname'] 			= $first_name;
				        $res_meta_datas['pur_lname'] 			= $last_name;
				        $res_meta_datas['pur_email'] 			= $email;

				        //strore Stripe customer id in the reg
				        $res_meta_datas['pur_customer_id'] 		= $customer_id ;
				        
			            // if(!empty($eventres_add_fields)){
			            //     foreach ($eventres_add_fields as $key => $field) {
			            //         $field_name = str_replace(array(" ","-"), "_", $field['name']);
			            //         if(!isset($res_meta_datas[$field_name])){
			            //             $res_meta_datas[$field_name] = trim($_POST[$field_name]); 
			            //         }
			            //     }
			            // }


	        			foreach ($res_meta_datas as $key => $value) {
			                if ( !add_post_meta( $res_id, $key, $value , true ) ) {
			                    echo sprintf(__('Insert subscription %s data failure','cth-gather-plugins'),$key);
			                }
			            }

			            // update reservation with charge id and status
			            if(!add_post_meta( $res_id, 'pur_txn_id', $subscription->id, true )){
							if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Can not add Stripe subscription id to reservation post pur_txn_id meta". PHP_EOL, 3, STRIPE_LOG_FILE);
							//print('Can not add stripe charge id to reservation post pur_txn_id meta');
						}
						// if(!add_post_meta( $res_id, 'pur_stripe_bl_txn', $charge->balance_transaction, true )){
						// 	print('Can not add stripe charge balance_transaction to reservation post pur_stripe_bl_txn meta');
						// }
						// if(!add_post_meta( $res_id, 'pur_payment_status', $charge->status, true )){
						// 	print('Can not add stripe charge status to reservation post pur_payment_status meta');
						// }

				    }

				}
				// redirect on successful recurring payment setup
				//$redirect = add_query_arg( 'payment', 'paid', get_permalink( $gather_stripe_options['stripe_success_page'] ) );

				$redirect = $success_redirect ;
 
			} catch (Exception $e) {
				// redirect on failure
				if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Stripe subscription error: " . $e->getMessage() . PHP_EOL, 3, STRIPE_LOG_FILE);
				//delete subscription if charge failed
				wp_delete_post( $res_id ) ;
				//$redirect = add_query_arg( 'payment', 'failed', get_permalink( $gather_stripe_options['stripe_success_page'] ) );

				$redirect = $failed_redirect ;
			}
 
		} else { // process a one-tiome payment

			$res_id = 0;

			try {
			  	// Use Stripe's library to make requests...
				//\Stripe\Stripe::setApiKey( get_option('eventres_stripe_secret_key' ) );

				$res_datas = array();
		        if(isset($first_name) && isset($last_name)){
		            $res_datas['post_title'] = $first_name .' '.$last_name;
		        }else{
		            $res_datas['post_title'] = $email;
		        }
		        
		        //$res_datas['post_name'] = '';
		        $res_datas['post_content'] = '';
		        //$res_datas['post_author'] = '0';// default 0 for no author assigned
		        $res_datas['post_status'] = 'publish';
		        $res_datas['post_type'] = 'cth_eventres';//cth_striperes

		        $res_id = wp_insert_post($res_datas ,true );

		        if (is_wp_error($res_id)) {
		            //print( $res_id->get_error_message() );
		            if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Insert charge post error: " . $res_id->get_error_message() . PHP_EOL, 3, STRIPE_LOG_FILE);

		            throw new Exception($res_id->get_error_message());

		        }

				// for option prices
			    $paypal_options = array();
			    //$paypal_options['on0'] = trim($_POST['on0']);
			    $paypal_options['os0'] = trim($_POST['os0']);
			    $prices_option = get_option('eventres_item_prices');
			    
			    if(!empty($prices_option)){
			    	$op_in = 0;
			    	foreach ($prices_option as $pr_arr) {
			    		$paypal_options['option_select'.$op_in] = trim($pr_arr['name']);
			    		$paypal_options['option_amount'.$op_in] = trim($pr_arr['value']);
			    		if($paypal_options['os0'] == trim($pr_arr['name'])){
			    			//for reservation meta data store
			    			$res_post_datas['price'] = trim($pr_arr['value']);
			    		}

			    		$op_in++;
			    	}
			    }else{
			    	$res_post_datas['price'] = '99';
			    	$paypal_options['option_select0'] = 'Default Pass';
			    	$paypal_options['option_amount0'] = '99';
			    }

			    



				$amount = $res_post_datas['price'] * $quantity;
				//format amount for stripe
				$amount = number_format($amount , 2 , '.','') * 100 ;

				if($using_discount){
					if($coupon_type === 'percent') {
						$amount *= 1 - $coupon_amount/100;
					}elseif($coupon_type === 'amount'){
						$amount -= $coupon_amount;
					}
				}

				//check if user is logged in or not
				if( is_user_logged_in() ){
					$customer_id = get_user_meta( get_current_user_id(), '_striperes_customer_id', true );
				}else{
					$customer_id = false;
				}

				$res_meta_datas = array();
		        $res_meta_datas['pur_pass']     = trim($_POST['os0']);
		        $res_meta_datas['pur_price']     = $res_post_datas['price'];
		        $res_meta_datas['pur_quantity']     = $quantity;
		        $res_meta_datas['pur_date']     = date( get_option('date_format'), current_time( 'timestamp' ) );
		        $res_meta_datas['pur_currency']     = $currency;

		        $res_meta_datas['pur_key'] = $pur_key;
		        $res_meta_datas['pur_custom'] = uniqid();
		        $res_meta_datas['pur_gateway']     = 'Stripe Card';// 'Stripe '.$charge->source->object;
		        $res_meta_datas['pur_status']     = 'Pending';// 'Completed';

		        
		        $res_meta_datas['pur_fname'] = $first_name;
		        $res_meta_datas['pur_lname'] = $last_name;
		        $res_meta_datas['pur_email'] = $email;

		        //strore Stripe customer id in the reg
		        $res_meta_datas['pur_customer_id'] = $customer_id ;

		        $chargeobjmeta = array();
		        $chargeobjmeta['res_id'] = $res_id;
		        $chargeobjmeta['event_pass']     = trim($_POST['os0']);
		        $chargeobjmeta['quantity']     = $quantity;

		        //$eventres_add_fields            = get_option('eventres_add_fields','' );
	            if(!empty($eventres_add_fields)){
	                foreach ($eventres_add_fields as $key => $field) {
	                    $field_name = str_replace(array(" ","-"), "_", $field['name']);
	                    if(!isset($res_meta_datas[$field_name])){
	                        $res_meta_datas[$field_name] = trim($_POST[$field_name]); 
	                        $chargeobjmeta[$field_name] = trim($_POST[$field_name]); 
	                    }
	                }
	            }

				if($customer_id){
					$charge = \Stripe\Charge::create(array(
					    'customer' => $customer_id,
					    'amount'   => $amount,
					    'currency' => $currency,
					    'description' => 'Reverse a seat' + $email,
					    'receipt_email' => $email,
					    'metadata' => $chargeobjmeta
					));
				}else{
					$customer = \Stripe\Customer::create(array(
					    'email' => $email,
					    'source'  => $token,
					    'metadata' => array( "first_name" => $first_name, "last_name" => $last_name ), // You can have up to 20 keys, with key names up to 40 characters long and values up to 500 characters long.
					));
					if( is_user_logged_in() ) {
						// add customer id to use later
						add_user_meta( get_current_user_id() , '_striperes_customer_id', $customer->id);
					}else{
						if(isset($gather_stripe_options['register_user']) && $gather_stripe_options['register_user'] ) {
							//register new user when register to event
							$new_username = sanitize_user($first_name.'_'.$last_name, true);
							$new_user = register_new_user($new_username, $email);
							if ( !is_wp_error($new_user) ) {
								
								add_user_meta( $new_user, '_striperes_customer_id', $customer->id);
								
							}else{
								if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Stripe one-time payment add new user error: " . $new_user->get_error_message() . PHP_EOL, 3, STRIPE_LOG_FILE);
							}
						}
					}
					$charge = \Stripe\Charge::create(array(
					    'customer' => $customer->id,
					    'amount'   => $amount,
					    'currency' => $currency,
					    'description' => 'Reverse a seat' + $email,
					    'receipt_email' => $email,
					    'metadata' => $chargeobjmeta
					));


					$customer_id = $customer->id;
				}

				//var_dump($amount);die;

				//update charge to send receipt to the buyer
				$newchargetoupdate = \Stripe\Charge::retrieve($charge->id);
				//$newchargetoupdate->receipt_email = $email; 
				//$charge->save();

				

				

				// echo '<pre>';
				// print_r($charge);

				// echo $charge->status;

				if($charge->status === 'succeeded'){
					// $res_datas = array();
			  //       if(isset($first_name) && isset($last_name)){
			  //           $res_datas['post_title'] = $first_name .' '.$last_name;
			  //       }else{
			  //           $res_datas['post_title'] = $email;
			  //       }
			        
			  //       //$res_datas['post_name'] = '';
			  //       $res_datas['post_content'] = '';
			  //       //$res_datas['post_author'] = '0';// default 0 for no author assigned
			  //       $res_datas['post_status'] = 'publish';
			  //       $res_datas['post_type'] = 'cth_striperes';//cth_striperes

			  //       $res_id = wp_insert_post($res_datas ,true );

			  //       if (is_wp_error($res_id)) {
			  //           print( $res_id->get_error_message() );
			  //       }else{

			        	//echo $charge->source->object;

			        	

			        	// $res_meta_datas = array();
				        // $res_meta_datas['pur_pass']     = trim($_POST['os0']);
				        // $res_meta_datas['pur_price']     = $res_post_datas['price'];
				        // $res_meta_datas['pur_quantity']     = $quantity;
				        // $res_meta_datas['pur_date']     = date( get_option('date_format'), current_time( 'timestamp' ) );
				        // $res_meta_datas['pur_currency']     = $currency;

				        // $res_meta_datas['pur_key'] = $pur_key;
				        // $res_meta_datas['pur_custom'] = uniqid();
				        // $res_meta_datas['pur_gateway']     = 'Stripe Card';// 'Stripe '.$charge->source->object;
				        // $res_meta_datas['pur_status']     = 'Completed';

				        
				        // $res_meta_datas['pur_fname'] = $first_name;
				        // $res_meta_datas['pur_lname'] = $last_name;
				        // $res_meta_datas['pur_email'] = $email;

				        // //strore Stripe customer id in the reg
				        // $res_meta_datas['pur_customer_id'] = $customer_id ;

				        // $chargeobjmeta = array();
				        // $chargeobjmeta['res_id'] = $res_id;
				        // $chargeobjmeta['event_pass']     = trim($_POST['os0']);
				        // $chargeobjmeta['quantity']     = $quantity;

				        // //$eventres_add_fields            = get_option('eventres_add_fields','' );
			         //    if(!empty($eventres_add_fields)){
			         //        foreach ($eventres_add_fields as $key => $field) {
			         //            $field_name = str_replace(array(" ","-"), "_", $field['name']);
			         //            if(!isset($res_meta_datas[$field_name])){
			         //                $res_meta_datas[$field_name] = trim($_POST[$field_name]); 
			         //                $chargeobjmeta[$field_name] = trim($_POST[$field_name]); 
			         //            }
			         //        }
			         //    }


	        			foreach ($res_meta_datas as $key => $value) {
			                if ( !add_post_meta( $res_id, $key, $value , true ) ) {
			                	if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Insert reservation $key data failure" . PHP_EOL, 3, STRIPE_LOG_FILE);
			                    
			                }
			            }
			            // foreach ($chargeobjmeta as $key => $value) {
			            //     $newchargetoupdate->metadata[$key] = $value;
			            // }

			            // update reservation with charge id and status
			            if(!add_post_meta( $res_id, 'pur_txn_id', $charge->id, true )){
			            	if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Can not add stripe charge id to reservation post pur_txn_id meta" . PHP_EOL, 3, STRIPE_LOG_FILE);
							//print('Can not add stripe charge id to reservation post pur_txn_id meta');
						}
						if(!add_post_meta( $res_id, 'pur_stripe_bl_txn', $charge->balance_transaction, true )){
							if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Can not add stripe charge balance_transaction to reservation post pur_stripe_bl_txn meta" . PHP_EOL, 3, STRIPE_LOG_FILE);
							//print('Can not add stripe charge balance_transaction to reservation post pur_stripe_bl_txn meta');
						}
						if(!update_post_meta( $res_id, 'pur_status', 'Completed' )){
							if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Can not update stripe charge status to reservation post pur_status meta to Completed" . PHP_EOL, 3, STRIPE_LOG_FILE);
							//print('Can not add stripe charge status to reservation post pur_payment_status meta');
						}
						if(!add_post_meta( $res_id, 'pur_payment_status', $charge->status, true )){
							if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Can not add stripe charge status to reservation post pur_payment_status meta" . PHP_EOL, 3, STRIPE_LOG_FILE);
							//print('Can not add stripe charge status to reservation post pur_payment_status meta');
						}


						// //emails
						// $sender_option = isset($gather_stripe_options['email_sender_name']) ? $gather_stripe_options['email_sender_name'] : 'Gather Event';
		    //         	$sender_email_option = isset($gather_stripe_options['email_sender_email']) ? $gather_stripe_options['email_sender_email'] : 'no-reply@cththemes.com';

		    //         	//new in version 2
		    //         	$allow_field_names = array('first_name','last_name','payer_email','receiver_email','item_name','item_number','quantity','payment_currency','payment_amount','event_pass','date','sitename','txn_id','res_id');
					    
					 //    if(!empty($eventres_add_fields)){
					 //        foreach ($eventres_add_fields as $key => $field) {
					 //            $field_name = str_replace(array(" ","-"), "_", $field['name']);
					 //            $allow_field_names[] = $field_name;
					 //            if(!isset($$field_name)){
					 //                $$field_name = get_post_meta( $res_id, $field_name, true );
					 //            }
					 //        }
					 //    }

					 //    $allow_field_names = array_unique($allow_field_names);

		    //         	//$eventres_confirmed_to_buyer_email = get_option('eventres_confirmed_to_buyer_email','yes');
		    //         	if($gather_stripe_options['success_email_to_buyer'] === 'yes') :
			   //          	// to buyer
			   //          	// if(get_post_meta( $res_id, 'pur_email', true ) == FALSE){
			   //          	// 	$buyer_mail_to = $payer_email;
			   //          	// }else{
			   //          	// 	$buyer_mail_to = get_post_meta( $res_id, 'pur_email', true );
			   //          	// }
			   //          	$buyer_mail_to = $mail;
			   //          	$buyer_mail_subject = $gather_stripe_options['success_email_to_buyer_subject']; 
						// 	$to_buyer_email_template = $gather_stripe_options['success_email_to_buyer_template']; 

			   //              if(preg_match_all("/{([\w-_]+)[^\w-_]*}/", $to_buyer_email_template, $matches)!= FALSE){
			   //                  $fieldsPattern = array();//$matches[0];
			   //                  $fieldsReplace = array();
			   //                  foreach ($matches[1] as $key => $fn) {
			   //                      $fieldsPattern[] = "/{(".$fn.")[^\w-_]*}/";

			   //                      if( isset($$fn) && in_array($fn, $allow_field_names ) ){
			   //                      	$fieldsReplace[] = $$fn;  //'['.$fn.']';
			   //                      }else{
			   //                      	$fieldsReplace[] = '{'.$fn.'}';
			   //                      }

			                        
			   //                  }


			   //                  $to_buyer_email_template = preg_replace($fieldsPattern, $fieldsReplace, $to_buyer_email_template);
			   //              }


			   //              $headers = array();
			   //              if($gather_stripe_options['email_content_type'] == 'html'){
			   //                  $headers[] = 'Content-Type: text/html; charset=UTF-8';
			   //              }
			   //              //$headers[] = 'From: '. $sender_option.' ' . '<'.$sender_email_option.'>';
			   //              add_filter( 'wp_mail_from_name', 'cth_gather_plugins_striperes_custom_wp_mail_from_name' );
			   //              add_filter('wp_mail_from', 'cth_gather_plugins_striperes_custom_wp_mail_from');

			   //              $headers[] = 'Reply-To: '. $sender_option.' ' . '<'.$sender_email_option.'>';

			   //              //$e_return = wp_mail( $mail_to, $mail_subject , $message, $headers);
			   //              wp_mail( $buyer_mail_to, $buyer_mail_subject , $to_buyer_email_template, $headers);
			              	
			   //            	remove_filter( 'wp_mail_from_name', 'cth_gather_plugins_striperes_custom_wp_mail_from_name' );
			   //            	remove_filter('wp_mail_from', 'cth_gather_plugins_striperes_custom_wp_mail_from');

			   //          endif;






			        //} //end create charge post
				}

				//Update charge
				//$newchargetoupdate->save();

				// echo '<h1>Successfully charged $50.00!</h1>';

				// echo '<pre>';
				// print_r($charge);

				// echo $charge->status;

				// echo $_POST['stripeEmail'];

				//$redirect = add_query_arg( 'payment', 'paid', get_permalink( $gather_stripe_options['stripe_success_page'] ) );

				$redirect = $success_redirect ;

			/*} catch(\Stripe\Error\Card $e) {
			  // Since it's a decline, \Stripe\Error\Card will be caught
			  $body = $e->getJsonBody();
			  $err  = $body['error'];

			  print('Status is:' . $e->getHttpStatus() . "\n");
			  print('Type is:' . $err['type'] . "\n");
			  print('Code is:' . $err['code'] . "\n");
			  // param is '' in this case
			  print('Param is:' . $err['param'] . "\n");
			  print('Message is:' . $err['message'] . "\n");
			} catch (\Stripe\Error\RateLimit $e) {
			  // Too many requests made to the API too quickly
			} catch (\Stripe\Error\InvalidRequest $e) {
			  // Invalid parameters were supplied to Stripe's API
			} catch (\Stripe\Error\Authentication $e) {
			  // Authentication with Stripe's API failed
			  // (maybe you changed API keys recently)
			} catch (\Stripe\Error\ApiConnection $e) {
			  // Network communication with Stripe failed
			} catch (\Stripe\Error\Base $e) {
			  // Display a very generic error to the user, and maybe send
			  // yourself an email */
			} catch (Exception $e) {
			  	// Something else happened, completely unrelated to Stripe
				if(STRIPE_DEBUG) error_log(date('[Y-m-d H:i e] '). "Stripe one-time payment error: " . $e->getMessage() . PHP_EOL, 3, STRIPE_LOG_FILE);

				wp_delete_post( $res_id ) ;
				// wp_trash_post( $res_id ) ;

				//$redirect = add_query_arg( 'payment', 'failed', get_permalink( $gather_stripe_options['stripe_success_page'] ) );

				$redirect = $failed_redirect ;
			}



 
			// // attempt to charge the customer's card
			// try {
			// 	$charge = Stripe_Charge::create(array(
			// 			'amount' => 1000, // $10
			// 			'currency' => 'usd',
			// 			'card' => $token
			// 		)
			// 	);
 
			// 	// redirect on successful payment
			// 	$redirect = add_query_arg('payment', 'paid', $_POST['redirect']);
 
			// } catch (Exception $e) {
			// 	// redirect on failed payment
			// 	$redirect = add_query_arg('payment', 'failed', $_POST['redirect']);
			// }

			//$redirect = add_query_arg( 'payment', 'paid', get_permalink(get_option('eventres_stripe_success_page' ) ) );
		}
 
		// redirect back to our previous page with the added query variable
		wp_redirect($redirect); exit;
	}
}
add_action('init', 'cth_eventres_plugin_stripe_process_payment_for_modal');


if(!function_exists('cth_gather_plugins_striperes_custom_wp_mail_from_name')){
	function cth_gather_plugins_striperes_custom_wp_mail_from_name( $name ) {
		global $gather_stripe_options;
	    return isset($gather_stripe_options['email_sender_name']) ? $gather_stripe_options['email_sender_name'] : 'Gather Event';
	}
}
if(!function_exists('cth_gather_plugins_striperes_custom_wp_mail_from')){
	function cth_gather_plugins_striperes_custom_wp_mail_from( $email ) {
		global $gather_stripe_options;
	    return isset($gather_stripe_options['email_sender_email']) ? $gather_stripe_options['email_sender_email'] : 'no-reply@cththemes.com';
	}
}
	

	



